Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MakeTestLog ¶
makeTestLog returns a *slog.Logger adapted for tests: it never reports the timestamp and by default it discards all the output. If on the other hand the tests are invoked in verbose mode (go test -v), then the logger will log normally.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.